@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Author::JQUELIN;
 {
-  $Dist::Zilla::PluginBundle::Author::JQUELIN::VERSION = '2.120971';
+  $Dist::Zilla::PluginBundle::Author::JQUELIN::VERSION = '3.000';
 }
 # ABSTRACT: Build & release a distribution like jquelin
 
@@ -22,18 +22,19 @@ use Moose::Autobox;
 
 # plugins used
 use Dist::Zilla::Plugin::AutoPrereqs;
-use Dist::Zilla::Plugin::AutoVersion;
 use Dist::Zilla::Plugin::Bugtracker;
 use Dist::Zilla::Plugin::CheckChangeLog;
-use Dist::Zilla::Plugin::Test::Compile 1.100220;
-#use Dist::Zilla::Plugin::CriticTests;
+use Dist::Zilla::Plugin::Covenant;
 use Dist::Zilla::Plugin::ExecDir;
 use Dist::Zilla::Plugin::ExtraTests;
 use Dist::Zilla::Plugin::GatherDir;
-use Dist::Zilla::Plugin::HasVersionTests;
+use Dist::Zilla::Plugin::Git::Check;
+use Dist::Zilla::Plugin::Git::Commit;
+use Dist::Zilla::Plugin::Git::NextVersion;
+use Dist::Zilla::Plugin::Git::Tag;
+use Dist::Zilla::Plugin::Git::Push;
+use Dist::Zilla::Plugin::HelpWanted;
 use Dist::Zilla::Plugin::Homepage;
-#use Dist::Zilla::Plugin::InstallGuide;
-use Dist::Zilla::Plugin::Test::Kwalitee;
 use Dist::Zilla::Plugin::License;
 use Dist::Zilla::Plugin::Manifest;
 use Dist::Zilla::Plugin::ManifestSkip;
@@ -41,26 +42,24 @@ use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MetaProvides::Package;
 use Dist::Zilla::Plugin::MetaYAML;
-#use Dist::Zilla::Plugin::MetaTests;
 use Dist::Zilla::Plugin::ModuleBuild;
-use Dist::Zilla::Plugin::Test::MinimumVersion;
 use Dist::Zilla::Plugin::NextRelease 2.101230;  # time_zone param
 use Dist::Zilla::Plugin::PkgVersion;
 use Dist::Zilla::Plugin::PodCoverageTests;
 use Dist::Zilla::Plugin::PodSyntaxTests;
 use Dist::Zilla::Plugin::PodWeaver;
-#use Dist::Zilla::Plugin::PortabilityTests;
 use Dist::Zilla::Plugin::Prepender 1.100130;
 use Dist::Zilla::Plugin::PruneCruft;
 use Dist::Zilla::Plugin::PruneFiles;
 use Dist::Zilla::Plugin::Readme;
+use Dist::Zilla::Plugin::ReadmeMarkdownFromPod;
 use Dist::Zilla::Plugin::ReportVersions::Tiny;
 use Dist::Zilla::Plugin::Repository;
 use Dist::Zilla::Plugin::ShareDir;
 use Dist::Zilla::Plugin::TaskWeaver;
-#use Dist::Zilla::Plugin::UnusedVarsTests;
+use Dist::Zilla::Plugin::Test::Compile 1.100220;
+use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::UploadToCPAN;
-use Dist::Zilla::PluginBundle::Git;
 
 with 'Dist::Zilla::Role::PluginBundle';
 with 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
@@ -77,21 +76,14 @@ sub bundle_config {
     # long list of plugins
     my @wanted = (
         # -- static meta-information
-        [ AutoVersion => { time_zone => 'Europe/Paris' } ],
+        [ 'Git::NextVersion' => {} ],
 
         # -- fetch & generate files
         [ GatherDir              => {} ],
         [ 'Test::Compile'        => {} ],
-        #[ CriticTests            => {} ],
-        [ HasVersionTests        => {} ],
-        [ 'Test::Kwalitee'       => {} ],
-        #[ MetaTests              => {} ],
-        [ 'Test::MinimumVersion' => {} ],
         [ PodCoverageTests       => {} ],
         [ PodSyntaxTests         => {} ],
-        #[ PortabilityTests       => {} ],
         [ 'ReportVersions::Tiny' => {} ],
-        #[ UnusedVarsTests        => {} ],
 
         # -- remove some files
         [ PruneCruft   => {} ],
@@ -118,27 +110,22 @@ sub bundle_config {
         [ MetaConfig              => {} ],
 
         # -- generate meta files
-        [ License      => {} ],
-        [ MetaYAML     => {} ],
-        [ MetaJSON     => {} ],
-        [ ModuleBuild  => {} ],
-        #[ InstallGuide => {} ],
-        [ Readme       => {} ],
-        [ Manifest     => {} ], # should come last
+        [ HelpWanted            => {} ],
+        [ License               => {} ],
+        [ Covenant              => {} ],
+        [ MetaYAML              => {} ],
+        [ MetaJSON              => {} ],
+        [ ModuleBuild           => {} ],
+        [ Readme                => {} ],
+        [ ReadmeMarkdownFromPod => {} ],
+        [ Manifest              => {} ], # should come last
 
         # -- release
         [ CheckChangeLog => {} ],
+        [ TestRelease    => {} ],
         [ "Git::Check"   => {} ],
         [ "Git::Commit"  => {} ],
-        [ "Git::CommitBuild" => {
-                branch         => '',
-                release_branch => $release_branch,
-            } ],
-        [ "Git::Tag"     => "TagMaster"  => {} ],
-        [ "Git::Tag"     => "TagRelease" => {
-                tag_format => 'cpan-v%v',
-                branch     => $release_branch,
-            } ],
+        [ "Git::Tag"     => {} ],
         [ "Git::Push"    => {} ],
 
         [ UploadToCPAN   => {} ],
@@ -167,6 +154,7 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
+__END__
 
 =pod
 
@@ -176,7 +164,7 @@ Dist::Zilla::PluginBundle::Author::JQUELIN - Build & release a distribution like
 
 =head1 VERSION
 
-version 2.120971
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -257,7 +245,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
